@@ -5,20 +5,14 @@
 SOURCE_NAME=syrthes
 VERSION=$2
 DEBIAN_VERSION=$VERSION-dfsg1
-UPSTREAM_SOURCE_DIR=${SOURCE_NAME}$VERSION
+UPSTREAM_SOURCE_DIR=${SOURCE_NAME}$VERSION-debian
 DEBIAN_SOURCE_DIR=${SOURCE_NAME}-$DEBIAN_VERSION
 TAR=../${SOURCE_NAME}_$DEBIAN_VERSION.orig.tar.gz
 
 # extract the upstream archive
-unzip $3 >/dev/null
+tar xf $3
 # rename upstream source dir
 mv ${UPSTREAM_SOURCE_DIR} ${DEBIAN_SOURCE_DIR}
-# convert text files from dos to unix
-for file in $(find ${DEBIAN_SOURCE_DIR} -type f); do
-  if file -b $file | egrep -w 'FORTRAN program|text' >/dev/null; then
-    fromdos -o $file
-  fi
-done
 # repack into orig.tar.gz without unwanted files
 tar -c -z -X debian/orig-tar.exclude -f $TAR ${DEBIAN_SOURCE_DIR}/
 rm -rf ${DEBIAN_SOURCE_DIR}
